@@ -6,7 +6,8 @@
 
 void dns_rcrw_info_free (struct dns_rcrw_info *d)
 {
+  struct taia zero = TAIA_ZERO ;
   d->uses = 0 ;
-  taia_uint(&d->deadline, 0) ;
+  d->deadline = zero ;
   stralloc_free(&d->rules) ;
 }
