@@ -8,6 +8,6 @@
 unsigned char badrandom_char (void)
 {
   unsigned char x ;
-  badrandom_string(&x, 1) ;
+  badrandom_string((char *)&x, 1) ;
   return x ;
 }
