@@ -8,6 +8,6 @@
 unsigned char goodrandom_char (void)
 {
   unsigned char x ;
-  goodrandom_string(&x, 1) ;
+  goodrandom_string((char *)&x, 1) ;
   return x ;
 }
