@@ -9,7 +9,7 @@ unsigned int randomegd_readb (int s, char *x, unsigned int n)
   unsigned int i = 0 ;
   for (; i < (n / 255) ; i++)
   {
-    unsigned char const c[2] = { 0x02, 0xFF } ;
+    char const c[2] = { 0x02, 0xFF } ;
     register unsigned char wtmp ;
     if (allwrite(s, c, 2) < 2) return w ;
     wtmp = allread(s, x + w, 255) ;
@@ -18,8 +18,8 @@ unsigned int randomegd_readb (int s, char *x, unsigned int n)
   }
   if (w < n)
   {
-    unsigned char c[2] = "\002" ;
-    c[1] = (unsigned char)(n - w) ;
+    char c[2] = "\002" ;
+    c[1] = n - w ;
     if (allwrite(s, c, 2) < 2) return w ;
     w += allread(s, x + w, c[1]) ;
   }
