@@ -10,7 +10,7 @@ struct SURFSchedule
 {
   uint32 seed[32] ;
   uint32 in[12] ;
-  unsigned char out[32] ;
+  char out[32] ;
   unsigned char pos ;
 } ;
 
