@@ -4,7 +4,7 @@
 
 void surf_init (SURFSchedule_ref ctx)
 {
-  unsigned char s[160] ;
+  char s[160] ;
   surf_makeseed(s) ;
   surf_sinit(ctx, s) ;
 }
