@@ -24,7 +24,7 @@ void surf_makeseed (char *s)
     sha1_update(&bak, tmp, 20) ;
   }  
   {
-    unsigned char i = 0 ;
+    char i = 0 ;
     for (; i < 8 ; i++)
     {
       SHA1Schedule ctx = bak ;
