@@ -14,7 +14,7 @@ void md5_update (MD5Schedule_ref ctx, char const *s, unsigned int len)
   t = (t >> 3) & 0x3f ;
   if (t)
   {
-    unsigned char *p = (unsigned char *)ctx->in + t ;
+    unsigned char *p = ctx->in + t ;
     t = 64 - t ;
     if (len < t)
     {
@@ -28,10 +28,10 @@ void md5_update (MD5Schedule_ref ctx, char const *s, unsigned int len)
   }
   while (len >= 64)
   {
-    byte_copy(ctx->in, 64, s) ;
+    byte_copy((char *)ctx->in, 64, s) ;
     uint32_little_endian(ctx->in, 16) ;
     md5_transform(ctx->buf, (uint32 *)ctx->in) ;
     s += 64 ; len -= 64 ;
   }
-  byte_copy(ctx->in, len, s) ;
+  byte_copy((char *)ctx->in, len, s) ;
 }
