@@ -4,7 +4,7 @@
 #include "bytestr.h"
 #include "rc4.h"
 
-void rc4 (RC4Schedule_ref r, unsigned char const *in, unsigned char *out, unsigned int n)
+void rc4 (RC4Schedule_ref r, char const *in, char *out, unsigned int n)
 {
   register unsigned int i = 0 ;
   for (; i < n ; i++)
@@ -15,6 +15,6 @@ void rc4 (RC4Schedule_ref r, unsigned char const *in, unsigned char *out, unsign
     r->y = T8(r->y + t) ;
     r->tab[r->x] = r->tab[r->y] ;
     r->tab[r->y] = t ;
-    out[i] = in[i] ^ T8(r->tab[r->x] + r->tab[r->y]) ;
+    out[i] = (unsigned char)in[i] ^ T8(r->tab[r->x] + r->tab[r->y]) ;
   }
 }
