@@ -17,6 +17,6 @@ struct SHA1Schedule
 #define SHA1_INIT() { {0x67452301UL, 0xefcdab89UL, 0x98badcfeUL, 0x10325476UL, 0xc3d2e1f0UL}, {0, 0}, {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 0 }
 extern void sha1_init (SHA1Schedule_ref) ;
 extern void sha1_update (SHA1Schedule_ref, char const *, unsigned int) ;
-extern void sha1_final (SHA1Schedule_ref, unsigned char * /* 20 chars */) ;
+extern void sha1_final (SHA1Schedule_ref, char * /* 20 chars */) ;
 
 #endif
