@@ -4,9 +4,9 @@
 #include "sha1.h"
 #include "sha1_internal.h"
 
-void sha1_final (SHA1Schedule_ref ctx, unsigned char *digest)
+void sha1_final (SHA1Schedule_ref ctx, char *digest)
 {
-  unsigned char pack[8] ;
+  char pack[8] ;
   register unsigned int i = 0 ;
   uint32_pack_big(pack, ctx->bits[1]) ;
   uint32_pack_big(pack+4, ctx->bits[0]) ;
