@@ -5,7 +5,7 @@
 
 #include "gccattributes.h"
 
-typedef unsigned char aligned_char gccattr_aligned ;
+typedef char aligned_char gccattr_aligned ;
 typedef aligned_char *aligned_char_ref, **aligned_char_ref_ref ;
 
 #ifdef USE_DJBALLOC
@@ -22,7 +22,7 @@ typedef aligned_char *aligned_char_ref, **aligned_char_ref_ref ;
 
 extern aligned_char_ref alloc (unsigned int) gccattr_malloc ;
 extern void alloc_free (void *) ;
-extern int alloc_re (unsigned char **, unsigned int, unsigned int) ;
-extern int alloc_realloc (unsigned char **, unsigned int) ;
+extern int alloc_re (void **, unsigned int, unsigned int) ;
+extern int alloc_realloc (void **, unsigned int) ;
 
 #endif
