@@ -13,16 +13,16 @@
 #include "alloc.h"
 
 #define ALIGNMENT 16
-typedef union { unsigned char blah[ALIGNMENT] ; double d ; } aligned ;
+typedef union { char blah[ALIGNMENT] ; double d ; } aligned ;
 
 #define SPACE 2048 /* must be multiple of ALIGNMENT */
 static aligned realspace[SPACE / ALIGNMENT] ;
-#define space ((unsigned char *) realspace)
+#define space ((char *) realspace)
 static unsigned int avail = SPACE ; /* multiple of ALIGNMENT; 0<=avail<=SPACE */
 
 void alloc_free (void *y)
 {
-  unsigned char *x = (unsigned char *)y ;
+  char *x = (char *)y ;
   if ((x >= space) && (x < space + SPACE))
     return ; /* XXX: assuming that pointers are flat (ndSka: they are) */
   free(y) ;
@@ -39,22 +39,23 @@ aligned_char_ref alloc (unsigned int n)
   return malloc(n) ;
 }
 
-int alloc_re (unsigned char **x, unsigned int m, unsigned int n)
+int alloc_re (void **x, unsigned int m, unsigned int n)
 {
   aligned_char_ref y = alloc(n) ;
   if (!y) return 0 ;
-  byte_copy(y, m, *x) ;
+  byte_copy(y, m, (char *)*x) ;
   alloc_free(*x) ;
   *x = y ;
   return 1 ;
 }
 
-int alloc_realloc (unsigned char **x, unsigned int n)
+int alloc_realloc (void **x, unsigned int n)
 {
-  if ((*x >= space) && (*x < space + SPACE)) return 0 ;
+  register char *z = *x ;
+  if ((z >= space) && (z < space + SPACE)) return 0 ;
   else
   {
-    aligned_char_ref y = realloc(*x, n) ;
+    aligned_char_ref y = realloc(z, n) ;
     if (!y) return 0 ;
     *x = y ;
     return 1 ;
