@@ -34,12 +34,12 @@ void alloc_free (void *p)
   strerr_warnw1x("alloc_free()") ;
 #endif
 #ifndef HASMALLOC0
-  if ((unsigned char *)p == alloc_0) return ;
+  if ((char *)p == alloc_0) return ;
 #endif
   free(p) ;
 }
 
-int alloc_realloc (unsigned char **x, unsigned int n)
+int alloc_realloc (void **x, unsigned int n)
 {
 #ifdef DEBUG_ALLOC
   {
@@ -58,7 +58,7 @@ int alloc_realloc (unsigned char **x, unsigned int n)
   return 1 ;
 }
 
-int alloc_re (unsigned char **x, unsigned int dummy, unsigned int n)
+int alloc_re (void **x, unsigned int dummy, unsigned int n)
 {
   (void)dummy ;
   return alloc_realloc(x, n) ;
