@@ -8,7 +8,7 @@
 
 char *basename (char *s)
 {
-  static stralloc basename_sa = GEN_ALLOC_ZERO ;
+  static stralloc basename_sa = STRALLOC_ZERO ;
   static char dot0[2] = "." ;
   char *dot = dot0 ;
   if (!s) return dot ;
