@@ -4,12 +4,11 @@
 #define BITARRAY_H
 
 #include "gccattributes.h"
-#include "gen_alloc.h"
 #include "uint64alloc.h"
 
 typedef struct bitarray { uint64alloc x ; } bitarray, *bitarray_ref ;
 
-#define BITARRAY_ZERO { GEN_ALLOC_ZERO }
+#define BITARRAY_ZERO { UINT64ALLOC_ZERO }
 
 extern int bitarray_ready (bitarray *, unsigned int) ;
 extern int bitarray_readyplus (bitarray *, unsigned int) ;
