@@ -3,7 +3,6 @@
 #ifndef BUFALLOC_H
 #define BUFALLOC_H
 
-#include "gen_alloc.h"
 #include "stralloc.h"
 
 typedef struct bufalloc bufalloc, *bufalloc_ref ;
@@ -15,8 +14,8 @@ struct bufalloc
   int (*op) (int, char const *, unsigned int) ;
 } ;
 
-#define BUFALLOC_ZERO { GEN_ALLOC_ZERO, 0, -1, 0 }
-#define BUFALLOC_INIT(op, fd) { GEN_ALLOC_ZERO, 0, (fd), (op) }
+#define BUFALLOC_ZERO { STRALLOC_ZERO, 0, -1, 0 }
+#define BUFALLOC_INIT(op, fd) { STRALLOC_ZERO, 0, (fd), (op) }
 extern void bufalloc_init (bufalloc_ref, int (*)(int, char const *, unsigned int), int) ;
 #define bufalloc_shrink(ba) stralloc_shrink(&(ba)->x)
 #define bufalloc_free(ba) stralloc_free(&(ba)->x)
