@@ -16,7 +16,8 @@ int buffer_getall (buffer_ref b, char *buf, unsigned int len, unsigned int *writ
   }
   while (*written < len)
   {
-    if (sanitize_read(buffer_fill(b)) <= 0) return -1 ;
+    register int r = sanitize_read(buffer_fill(b)) ;
+    if (r <= 0) return r ;
     *written += buffer_getnofill(b, buf + *written, len - *written) ;
   }
   *written = 0 ;
