@@ -5,7 +5,6 @@
 #include "uint32.h"
 #include "diuint32.h"
 #include "diuint32alloc.h"
-#include "gen_alloc.h"
 #include "buffer.h"
 #include "djbunix.h"
 #include "cdb.h"
@@ -22,7 +21,7 @@ static void cdb_make_free (struct cdb_make *c)
 
 int cdb_make_start (struct cdb_make *c, int fd)
 {
-  diuint32alloc zero = GEN_ALLOC_ZERO ;
+  diuint32alloc zero = DIUINT32ALLOC_ZERO ;
   c->hplist = zero ;
   c->fd = fd ;
   c->pos = 2048 ;
@@ -82,7 +81,7 @@ int cdb_make_finish (struct cdb_make *c)
   uint32 count[256] ;
   uint32 start[256] ;
   char final[2048] ;
-  diuint32alloc split = GEN_ALLOC_ZERO ;
+  diuint32alloc split = DIUINT32ALLOC_ZERO ;
   unsigned int n = c->hplist.len ;
   register unsigned int i = 0 ;
   register diuint32 *hp = c->hplist.s ;
