@@ -6,7 +6,6 @@
 #include "uint32.h"
 #include "diuint32alloc.h"
 #include "buffer.h"
-#include "gen_alloc.h"
 
 typedef struct cdb_make cdb_make, *cdb_make_ref ;
 struct cdb_make
@@ -18,7 +17,7 @@ struct cdb_make
   int fd ;
 } ;
 
-#define CDB_MAKE_ZERO { "", GEN_ALLOC_ZERO, BUFFER_INIT(&buffer_unixwrite, -1, 0, 0), 2048, -1 }
+#define CDB_MAKE_ZERO { "", DIUINT32ALLOC_ZERO, BUFFER_INIT(&buffer_unixwrite, -1, 0, 0), 2048, -1 }
 
 extern int cdb_make_start (struct cdb_make *, int) ;
 extern int cdb_make_add (struct cdb_make *, char const *, unsigned int, char const *, unsigned int) ;
