@@ -3,13 +3,12 @@
 /* MT-unsafe */
 
 #include "bytestr.h"
-#include "gen_alloc.h"
 #include "stralloc.h"
 #include "djbunix.h"
 
 char *dirname (char *s)
 {
-  static stralloc dirname_sa = GEN_ALLOC_ZERO ;
+  static stralloc dirname_sa = STRALLOC_ZERO ;
   static char dot0[2] = "." ;
   char *dot = dot0 ;
   if (!s) return dot ;
