@@ -5,7 +5,7 @@
 
 int doublefork ()
 {
-  unsigned char pack[4] ;
+  char pack[4] ;
   int fd[2] ;
   int child ;
   if (pipe(fd) == -1) return -1 ;
