@@ -4,6 +4,6 @@
 
 unsigned char fmtscan_asc (unsigned char c)
 {
-  unsigned char const tab[36] = "0123456789abcdefghijklmnopqrstuvwxyz" ;
+  static char const *tab = "0123456789abcdefghijklmnopqrstuvwxyz" ;
   return (c >= 36) ? 0 : tab[c] ;
 }
