@@ -37,10 +37,16 @@ GEN_ALLOC_FPROTOTYPES(ta, type, s, len, a) \
 #define GEN_ALLOC_ready(ta, type, s, len, a, base) \
 int ta##_ready (register ta *x, register unsigned int n) \
 { \
-  if (!x->s) return !!(x->s = (type *)alloc((x->a = n) * sizeof(type))) ; \
-  if (n > x->a) \
+  register unsigned int t = (base) + n + (n >> 3) ; \
+  if (!x->s) \
+  { \
+    type *p = (type *)alloc(t * sizeof(type)) ; \
+    if (!p) return 0 ; \
+    x->s = p ; \
+    x->a = t ; \
+  } \
+  else if (n > x->a) \
   { \
-    register unsigned int t = (base) + n + (n >> 3) ; \
     if (!alloc_re((void **)(void *)(&x->s), x->a * sizeof(type), t * sizeof(type))) \
       return 0 ; \
     x->a = t ; \
