@@ -12,5 +12,5 @@ unsigned int int_scan (char const *s, int *n)
     *n = (*s == '-') ? -tmp : tmp ;
     return r + 1 ;
   }
-  return uint_scan(s, n) ;
+  return uint_scan(s, (unsigned int *)n) ;
 }
