@@ -12,5 +12,5 @@ unsigned int long_scan (char const *s, long *n)
     *n = (*s == '-') ? -tmp : tmp ;
     return r + 1 ;
   }
-  return ulong_scan(s, n) ;
+  return ulong_scan(s, (unsigned long *)n) ;
 }
