@@ -10,6 +10,6 @@
 
 int ndelay_on (int fd)
 {
-  int got = fcntl(fd, F_GETFL) ;
+  register int got = fcntl(fd, F_GETFL) ;
   return (got == -1) ? -1 : fcntl(fd, F_SETFL, got | O_NONBLOCK) ;
 }
