@@ -2,13 +2,12 @@
 
 /* MT-unsafe */
 
-#include "gen_alloc.h"
 #include "stralloc.h"
 #include "env.h"
 #include "djbunix.h"
 #include "skamisc.h"
 
-static stralloc plus = GEN_ALLOC_ZERO ;
+static stralloc plus = STRALLOC_ZERO ;
 
 int pathexec_env (char const *s, char const *t) /* historic, bad name */
 {
