@@ -12,7 +12,7 @@ int sauniquename (stralloc *sa)
   unsigned int base = sa->len ;
   unsigned char wasnull = !sa->s ;
 
-  if (!stralloc_readyplus(sa, TIMESTAMP + FMT_ULONG + 131)) return -1 ;
+  if (!stralloc_readyplus(sa, TIMESTAMP + UINT_FMT + 131)) return -1 ;
   sa->s[base] = ':' ;
   timestamp(sa->s + base + 1) ;
   sa->s[base + 1 + TIMESTAMP] = ':' ;
