@@ -13,7 +13,7 @@
 #include "selfpipe.h"
 
 static int selfpipe[2] = { -1, -1 } ;
-static uint64 caught = 0 ;
+static uint64 caught ;
 
 static void selfpipe_trigger (int s)
 {
@@ -21,7 +21,7 @@ static void selfpipe_trigger (int s)
   fd_write(selfpipe[1], &c, 1) ;
 }
 
-static void selfpipe_close ()
+static void selfpipe_close (void)
 {
   register int e = errno ;
   fd_close(selfpipe[1]) ;
@@ -30,7 +30,7 @@ static void selfpipe_close ()
   errno = e ;
 }
 
-int selfpipe_init ()
+int selfpipe_init (void)
 {
   if (selfpipe[0] >= 0) return (errno = EBUSY, -1) ;
   if (pipe(selfpipe) == -1) return -1 ;
@@ -50,14 +50,14 @@ int selfpipe_trap (int sig)
   return 0 ;
 }
 
-int selfpipe_read ()
+int selfpipe_read (void)
 {
   char c ;
   register int r = sanitize_read((fd_read(selfpipe[0], &c, 1))) ;
   return (r <= 0) ? r : (int)c ;
 }
 
-void selfpipe_finish ()
+void selfpipe_finish (void)
 {
   register unsigned int i = 1 ;
   for (; i <= NSIG ; caught >>= 1, i++) if (caught & 1) sig_restore(i) ;
