@@ -12,5 +12,5 @@ unsigned int short_scan (char const *s, short *n)
     *n = (*s == '-') ? -tmp : tmp ;
     return r + 1 ;
   }
-  return ushort_scan(s, n) ;
+  return ushort_scan(s, (unsigned short *)n) ;
 }
