@@ -17,6 +17,6 @@ void sig_unshield ()
   sigaddset(&ss, SIGHUP) ;
   sigprocmask(SIG_UNBLOCK, &ss, 0) ;
 #else
-  sigsetmask(sigsetmask(~0) & ~((1 << (SIGTERM-1)) | (1 << (SIGQUIT-1)) | (1 << (SIGABRT-1)) | (1 << (SIGINT-1)) | (1 << (SIGPIPE-1)) | (1 << (SIGHUP-1))) ;
+  sigsetmask(sigsetmask(~0) & ~((1 << (SIGTERM-1)) | (1 << (SIGQUIT-1)) | (1 << (SIGABRT-1)) | (1 << (SIGINT-1)) | (1 << (SIGPIPE-1)) | (1 << (SIGHUP-1)))) ;
 #endif
 }
