@@ -9,6 +9,7 @@
 int skagetln (buffer_ref b, stralloc *sa, int sep)
 {
   unsigned int len = sa->len ;
+  int ok = 1 ;
   for (;;)
   {
     char *s = buffer_PEEK(b) ;
@@ -20,10 +21,11 @@ int skagetln (buffer_ref b, stralloc *sa, int sep)
     {
       if (!stralloc_catb(sa, buffer_PEEK(b), 1)) return -1 ;
       buffer_SEEK(b, 1) ;
-      return 1 ;
+      return ok ;
     }
     r = buffer_fill(b) ;
     if (r == -1) return -1 ;
     if (!r) return (sa->len > len) ? (errno = EPIPE, -1) : 0 ;
+    ok = 2 ;
   }
 }
