@@ -12,7 +12,7 @@
 int socket_accept4 (int s, char *ip, uint16 *port)
 {
   struct sockaddr_in sa ;
-  int dummy = sizeof sa ;
+  socklen_t dummy = sizeof sa ;
   register int fd ;
   do
     fd = accept(s, (struct sockaddr *)&sa, &dummy) ;
