@@ -10,7 +10,7 @@
 int socket_connected (int s)
 {
   struct sockaddr_in sa ;
-  int dummy = sizeof sa ;
+  socklen_t dummy = sizeof sa ;
   if (getpeername(s, (struct sockaddr *)&sa, &dummy) == -1)
   {
     char ch ;
