@@ -12,7 +12,7 @@
 int socket_recv4 (int s, char *buf, int len, char *ip, uint16 *port)
 {
   struct sockaddr_in sa ;
-  int dummy = sizeof sa ;
+  socklen_t dummy = sizeof sa ;
   register int r ;
   do r = recvfrom(s, buf, len, 0, (struct sockaddr *)&sa, &dummy) ;
   while ((r == -1) && (errno == EINTR)) ;
