@@ -11,7 +11,7 @@
 int socket_remote4 (int s, char *ip, uint16 *port)
 {
   struct sockaddr_in sa ;
-  int dummy = sizeof sa ;
+  socklen_t dummy = sizeof sa ;
 
   if (getpeername(s, (struct sockaddr *)&sa, &dummy) == -1)
     return -1 ;
