@@ -8,7 +8,7 @@ unsigned int uint64_fmt_base (char *s, uint64 x, unsigned char base)
   register unsigned int len = 1 ;
   {
     register uint64 q = x ;
-    while (q > (unsigned char)(base-1)) { len++ ; q /= base ; }
+    while (q > base-1) { len++ ; q /= base ; }
   }
   if (s)
   {
