@@ -5,7 +5,7 @@
 
 int uncoe (int fd)
 {
-   int flags = fcntl(fd, F_GETFD, 0) ;
+   register int flags = fcntl(fd, F_GETFD, 0) ;
    if (flags == -1) return -1 ;
    return fcntl(fd, F_SETFD, flags & ~FD_CLOEXEC) ;
 }
