@@ -33,7 +33,7 @@ int wait_pid (int *wstat, int pid)
 #include "diuint.h"
 #include "diuintalloc.h"
 
-static diuintalloc zombies = GEN_ALLOC_ZERO ;
+static diuintalloc zombies = DIUINTALLOC_ZERO ;
 
 int wait_nohang (int *wstat)
 {
