@@ -15,7 +15,7 @@ int wait_pids_nohang (int *wstat, int const *pids, unsigned int len)
         if (r == pids[i])
         {
           *wstat = w ;
-          return i ;
+          return 1+i ;
         }
     }
   }
