@@ -18,18 +18,18 @@
 
 int getpeereid (int s, int *u, int *g)
 {
-  struct ucred dummy = { 0, 0, 0 } ;
-  unsigned int len = sizeof(dummy) ;
+  struct ucred blah = { 0, 0, 0 } ;
+  unsigned int len = sizeof(blah) ;
 
-  if (getsockopt(s, SOL_SOCKET, SO_PEERCRED, &dummy, &len) == -1)
+  if (getsockopt(s, SOL_SOCKET, SO_PEERCRED, &blah, &len) == -1)
     return -1 ;
-  *u = dummy.uid ;
-  *g = dummy.gid ;
+  *u = blah.uid ;
+  *g = blah.gid ;
   return 0 ;
 }
 
 #else
-/* nonexistent getpeereid : dummy implementation */
+/* nonexistent getpeereid : stub implementation */
 
 #include <errno.h>
 
