@@ -8,10 +8,10 @@
 #include "bytestr.h"
 #include "webipc.h"
 
-int ipc_accept (int s, char *p, int l, int *trunc)
+int ipc_accept (int s, char *p, unsigned int l, int *trunc)
 {
   struct sockaddr_un sa ;
-  int dummy = sizeof sa ;
+  socklen_t dummy = sizeof sa ;
   register int fd ;
   byte_zero((char*)&sa, (unsigned int)dummy) ;
   do
