@@ -7,10 +7,10 @@
 #include "bytestr.h"
 #include "webipc.h"
 
-int ipc_local (int s, char *p, int l, int *trunc)
+int ipc_local (int s, char *p, unsigned int l, int *trunc)
 {
   struct sockaddr_un sa ;
-  int dummy = sizeof sa ;
+  socklen_t dummy = sizeof sa ;
   byte_zero((char *)&sa, sizeof sa) ;
   if (getsockname(s, (struct sockaddr *)&sa, &dummy) == -1) return -1 ;
   dummy = byte_chr(sa.sun_path, dummy, 0) ;
