@@ -44,8 +44,7 @@ int main ()
 {
   char a[64] ;
   char b[64] ;
-  int fd ;
-  fd = open("/dev/random", O_RDONLY) ;
+  int fd = open("/dev/random", O_RDONLY) ;
   if ((fd == -1) || (allread(fd, a, 64) < 64) ) return 111 ;
   close(fd) ;
   fd = open("/dev/random", O_RDONLY) ;
